<?php 
namespace Teknisa\MAN\Controllers\DataExporterImpl\ReportHandlers;

use Zeedhi\Framework\DTO\Response;
use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Services\RelVendasProdutoPeriodoporModo;

class RelVendasProdutoPeriodoporModoReportHandler extends AReportHandler {
    
    const ANALITICO = 'vnd55008_relVendasProdutoPeriodoporModoAnalitico';
    const SINTETICO = 'vnd55008_relVendasProdutoPeriodoporModoSintetico';
    
    
    public function __construct ($relService, RelVendasProdutoPeriodoporModo $relatorioService) {
        $this->relService = $relService;
        $this->relatorioService = $relatorioService;
    }
    
    public function buildNewRequest($request, Response $response) {
        
        $conditions = $this->relService->getParamsAsArray($request);
        $modalidades = 'MES_BAL_DLV_TAA_CMD';
        $conditions = $this->buildParamsForRel($conditions, $modalidades);
        $result = $this->findVendasProdMod($conditions);
        unset($conditions['NRORG']);
        $conditions['CDNVPRODUTO'] = $this->relatorioService->getMAXCDNVPRODUTO();
        
        $newRequest = $this->relService->createNewZeedhiFilterRequestObject($request, $result, $conditions);
        return [$newRequest, $response];
    }
    
    public function findVendasProdMod($params){
        $tipo = array_key_exists('TIPORELATORIO', $params) ? $params['TIPORELATORIO']:'A';
        return $this->getQuery($tipo);
    }
    
    public function getQuery($tipo){
        if($tipo === 'A'){
            return self::ANALITICO;
        }else{
            return self::SINTETICO;
        }
    }
    
    public function buildParamsForRel($conditions, $modalidade){
        
        $conditions = $this->addParams($conditions,'CDFILIAL');
        $conditions = $this->addParams($conditions,'CDLOJA');
        $conditions = $this->addParams($conditions,'DAYSOFWEEK');
        
        $conditions = $this->buildParamsDataAbertur($conditions);
        $conditions = $this->buildParamsModalidade($conditions,$modalidade);
        
        $conditions = $this->builParamsProduto($conditions);
        return $conditions;
        
    }
    
    public function addParams($conditions,$param){
        
        if(!array_key_exists($param, $conditions)) {
            $conditions[$param] = '';
            $conditions['T'.$param] = 'T';
        }else{
            $conditions[$param] = implode('_', $conditions[$param]);
            $conditions['T'.$param] = '';
        }
        return $conditions;
    }
    
    public function buildParamsDataAbertur($conditions){
        if(array_key_exists('DTENTRVENDA', $conditions)) {
            $conditions['DTINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTFIM'] = $conditions['DTENTRVENDA'][1];
        }
        unset($conditions['DTENTRVENDA']);
        return $conditions;
    }
    
    public function buildParamsModalidade($conditions,$modalidade){
        if(!array_key_exists('MODALIDADE', $conditions)) {
            $conditions['MODALIDADE'] = $modalidade;
        } else {
            $conditions['MODALIDADE'] = implode('_', $conditions['MODALIDADE']);
        }
        return $conditions;
    }
    
    public function getProdutos($params){
        $conditions = '';
        if(!empty($params)){
          $conditions = implode('_', $params);  
        }
        return $conditions;
    }
    
    public function builParamsProduto($conditions){
        if( !array_key_exists('CDARVPRODI', $conditions) && 
            !array_key_exists('CDARVPRODF', $conditions) &&
            !array_key_exists('CDARVPROD', $conditions)) {
            
            $conditions['CDPRODINI'] = $conditions['CDPRODFIM'] = null;    
            $conditions['TCDPRODUTO'] = 'T';
            $conditions['CDPRODS'] = null;
        } else {
            if( array_key_exists('CDARVPRODI', $conditions) && 
                !array_key_exists('CDARVPRODF', $conditions)) {
                $conditions['CDARVPRODF'] = $conditions['CDARVPRODI'];
            }
            
            if( !array_key_exists('CDARVPRODI', $conditions) && 
                !array_key_exists('CDARVPRODF', $conditions)) {
                
                
                $conditions['CDPRODS'] = $this->getProdutos($conditions['CDARVPROD']);
                unset($conditions['CDARVPROD']);
            } else {
                $params = array(
                    ':CDPRODINI' =>  str_replace("%", "",$conditions['CDARVPRODI']),
                    ':CDPRODFIM' =>  str_replace("%", "",$conditions['CDARVPRODF'])
                );
                
                $conditions['CDPRODS'] = $this->relatorioService->getIntervalo($params);
            }
            
            $conditions['TCDPRODUTO'] = null;
            unset($conditions['CDARVPRODI']);
            unset($conditions['CDARVPRODF']);
            unset($conditions['NMPRODUTO']);
        }
        return $conditions;
    }
    
}