<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource\Manager\SQL\ManagerImpl;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class Store extends Crud {
	
	protected $dataSourceName = 'store';
	protected $storeService;
    protected $salesMessage;
    protected $util;

	public function __construct(ManagerImpl $dataSourceManager, Services\Store $storeService, Utilities\SalesMessage $salesMessage, Utilities\Util $util){
        $this->storeService  = $storeService;
        $this->salesMessage  = $salesMessage;
        $this->util          = $util;
        parent::__construct($dataSourceManager);
    }

    public function loadStoreDataGraph (Request\Filter $request, Response $response){
        try {
            $storeData = $this->storeService->getStoreDataGraph();
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('StoreDataRepositoryGraph', $storeData));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function loadStoreData (Request\Filter $request, Response $response){
        try {
        	$params = $request->getFilterCriteria()->getConditions();
            $situation = $params[0]['value'];
            if($situation == \Service\Store::NEGATIVO){
                $storeData = $this->storeService->getCaixasNegativos();
            }
            else if($situation == \Service\Store::ATRASADO){
                $storeData = $this->storeService->getCaixasAtrasados();
            }
            else if($situation == \Service\Store::EM_DIA){
            	$storeData = $this->storeService->getCaixasEmDia();
            }
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('StoreDataRepository', $storeData));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
}